<% if @request_headers and ! @request_headers.empty? -%>

  ## Request header rules
  ## as per http://httpd.apache.org/docs/2.2/mod/mod_headers.html#requestheader
  <%- Array(@request_headers).each do |request_statement| -%>
    <%- if request_statement != '' -%>
  RequestHeader <%= request_statement %>
    <%- end -%>
  <%- end -%>
<% end -%>
