<IfModule mod_userdir.c>
<% if @disable_root -%>
  UserDir disabled root
<% end -%>
  UserDir <%= @dir %>

  <Directory <%= @home %>/*/<%= @dir %>>
    AllowOverride FileInfo AuthConfig Limit Indexes
    Options MultiViews Indexes SymLinksIfOwnerMatch IncludesNoExec
    <Limit GET POST OPTIONS>
      Order allow,deny
      Allow from all
    </Limit>
    <LimitExcept GET POST OPTIONS>
      Order deny,allow
      Deny from all
    </LimitExcept>
  </Directory>
</IfModule>
