<% if @aliases and ! @aliases.empty? -%>
  ## Alias declarations for resources outside the DocumentRoot
  <%- [@aliases].flatten.compact.each do |alias_statement| -%>
    <%- if alias_statement["path"] != '' -%>
      <%- if alias_statement["alias"] and alias_statement["alias"] != '' -%>
  Alias <%= alias_statement["alias"] %> <%= alias_statement["path"] %>
      <%- elsif alias_statement["aliasmatch"] and alias_statement["aliasmatch"] != '' -%>
  AliasMatch <%= alias_statement["aliasmatch"] %> <%= alias_statement["path"] %>
      <%- end -%>
    <%- end -%>
  <%- end -%>
<% end -%>
