<IfModule alias_module>
Alias /icons/ "<%= @icons_path %>/"
<Directory "<%= @icons_path %>">
    Options Indexes MultiViews
    AllowOverride None
    Order allow,deny
    Allow from all
</Directory>
</IfModule>
