# Enable reverse proxy add forward
RPAFenable On
# RPAFsethostname will, when enabled, take the incoming X-Host header and
# update the virtual host settings accordingly. This allows to have the same
# hostnames as in the "real" configuration for the forwarding proxy.
<% if @sethostname -%>
RPAFsethostname On
<% else -%>
RPAFsethostname Off
<% end -%>
# Which IPs are forwarding requests to us
RPAFproxy_ips <%= Array(@proxy_ips).join(" ") %>
# Setting RPAFheader allows you to change the header name to parse from the
# default X-Forwarded-For to something of your choice.
RPAFheader <%= @header %>
