# The WSGI Apache module configuration file is being
# managed by Puppet an changes will be overwritten.
<IfModule mod_wsgi.c>
  <%- if @wsgi_socket_prefix -%>
  WSGISocketPrefix <%= @wsgi_socket_prefix %>
  <%- end -%>
  <%- if @wsgi_python_home -%>
  WSGIPythonHome <%= @wsgi_python_home %>
  <%- end -%>
  <%- if @wsgi_python_path -%>
  WSGIPythonPath <%= @wsgi_python_path %>
  <%- end -%>  
</IfModule>
