<% if @itk and ! @itk.empty? -%>
  ## ITK statement
  <IfModule mpm_itk_module>
     <%- if @itk["user"] and @itk["group"] -%>
     AssignUserId <%= @itk["user"] %> <%= @itk["group"] %>
     <%- end -%>
     <%- if @itk["assignuieridexpr"] -%>
     AssignUserIdExpr <%= @itk["assignuieridexpr"] %>
     <%- end -%>
     <%- if @itk["assignuiergroupexpr"] -%>
     AssignGroupIdExpr <%= @itk["assignuiergroupexpr"] %>
     <%- end -%>
     <%- if @itk["maxclientvhost"] -%>
     MaxClientsVHost <%= @itk["maxclientvhost"] %>
     <%- end -%>
     <%- if @itk["nice"] -%>
     NiceValue <%= @itk["nice"] %>
     <%- end -%>
     <%- if @kernelversion >= '3.5.0' -%>
       <%- if @itk["limituidrange"] -%>
     LimitUIDRange <%= @itk["limituidrange"] %>
       <%- end -%>
       <%- if @itk["limitgidrange"] -%>
     LimitGIDRange <%= @itk["limitgidrange"] %>
       <%- end -%>
     <%- end -%>
  </IfModule>
<% end -%>
