<Location /server-status>
    SetHandler server-status
    Order deny,allow
    Deny from all
    Allow from <%= Array(@allow_from).join(" ") %>
</Location>
ExtendedStatus <%= @extended_status %>

<IfModule mod_proxy.c>
    # Show Proxy LoadBalancer status in mod_status
    ProxyStatus On
</IfModule>
