<% if @wsgi_daemon_process and @wsgi_daemon_process_options -%>
  WSGIDaemonProcess <%= @wsgi_daemon_process %> <%= @wsgi_daemon_process_options.collect { |k,v| "#{k}=#{v}"}.sort.join(' ') %>
<% elsif @wsgi_daemon_process and !@wsgi_daemon_process_options -%>
  WSGIDaemonProcess <%= @wsgi_daemon_process %>
<% end -%>
<% if @wsgi_process_group -%>
  WSGIProcessGroup <%= @wsgi_process_group %>
<% end -%>
<% if @wsgi_script_aliases and ! @wsgi_script_aliases.empty? -%>
  <%- @wsgi_script_aliases.each do |a, p| -%>
    <%- if a != '' and p != ''-%>
  WSGIScriptAlias <%= a %> <%= p %>
    <%- end -%>
  <%- end -%>
<% end -%>
