<% if @setenv and ! @setenv.empty? -%>

  ## SetEnv/SetEnvIf for environment variables
<% Array(@setenv).each do |envvar| -%>
  SetEnv <%= envvar %>
<% end -%>
<% end -%>
<% if @setenvif and ! @setenvif.empty? -%>
<% Array(@setenvif).each do |envifvar| -%>
  SetEnvIf <%= envifvar %>
<% end -%>
<% end -%>
