<% if @fastcgi_server -%>

  FastCgiExternalServer <%= @fastcgi_server %> -socket <%= @fastcgi_socket %>
<% end -%>
<% if @fastcgi_dir -%>

  <Directory <%= @fastcgi_dir %>>
    Options +ExecCGI
    AllowOverride All
    SetHandler fastcgi-script
    Order allow,deny
    Allow from all
    AuthBasicAuthoritative Off
  </Directory>

  AllowEncodedSlashes On
  ServerSignature Off
<% end -%>
