# The Passanger Apache module configuration file is being
# managed by Puppet and changes will be overwritten.
<IfModule mod_passenger.c>
  PassengerRoot <%= @passenger_root %>
  PassengerRuby <%= @passenger_ruby %>
  <%- if @passenger_high_performance -%>
  PassengerHighPerformance <%= @passenger_high_performance %>
  <%- end -%>
  <%- if @passenger_max_pool_size -%>
  PassengerMaxPoolSize <%= @passenger_max_pool_size %>
  <%- end -%>
  <%- if @passenger_pool_idle_time -%>
  PassengerPoolIdleTime <%= @passenger_pool_idle_time %>
  <%- end -%>
  <%- if @passenger_max_requests -%>
  PassengerMaxRequests <%= @passenger_max_requests %>
  <%- end -%>
  <%- if @passenger_stat_throttle_rate -%>
  PassengerStatThrottleRate <%= @passenger_stat_throttle_rate %>
  <%- end -%>
  <%- if @rack_autodetect -%>
  RackAutoDetect <%= @rack_autodetect %>
  <%- end -%>
  <%- if @rails_autodetect -%>
  RailsAutoDetect <%= @rails_autodetect %>
  <%- end -%>
  <%- if @passenger_use_global_queue -%>
  PassengerUseGlobalQueue <%= @passenger_use_global_queue %>
  <%- end -%> 
</IfModule>
