<% if @block and ! @block.empty? -%>

  ## Block access statements
<% if @block.include? 'scm' -%>
  # Block access to SCM directories.
  <DirectoryMatch .*\.(svn|git|bzr)/.*>
    Deny From All
  </DirectoryMatch>
<% end -%>
<% end -%>
