<IfModule mpm_peruser_module>
  MinSpareProcessors  <%= @minspareprocessors %>
  MinProcessors       <%= @minprocessors %>
  MaxProcessors       <%= @maxprocessors %>
  MaxClients          <%= @maxclients %>
  MaxRequestsPerChild <%= @maxrequestsperchild %>
  IdleTimeout         <%= @idletimeout %>
  ExpireTimeout       <%= @expiretimeout %>
  KeepAlive           <%= @keepalive %>
  Include             <%= @mod_dir %>/peruser/multiplexers/*.conf
  Include             <%= @mod_dir %>/peruser/processors/*.conf
</IfModule>
