#
# Proxy Server directives. Uncomment the following lines to
# enable the proxy server:
#
<IfModule mod_proxy.c>
  # Do not enable proxying with ProxyRequests until you have secured your
  # server.  Open proxy servers are dangerous both to your network and to the
  # Internet at large.
  ProxyRequests <%= @proxy_requests %>

  <% if @proxy_requests != 'Off' or ( @allow_from and ! @allow_from.empty? ) -%>
  <Proxy *>
    Order deny,allow
    Deny from all
    Allow from <%= Array(@allow_from).join(" ") %>
  </Proxy>
  <% end -%>

  # Enable/disable the handling of HTTP/1.1 "Via:" headers.
  # ("Full" adds the server version; "Block" removes all outgoing Via: headers)
  # Set to one of: Off | On | Full | Block
  ProxyVia On
</IfModule>
