<% if @proxy_dest or @proxy_pass -%>

  ## Proxy rules
  ProxyRequests Off
<%- end -%>
<% [@proxy_pass].flatten.compact.each do |proxy| %>
  ProxyPass <%= proxy['path'] %> <%= proxy['url'] %>
  <Location <%= proxy['path']%>>
    ProxyPassReverse /
  </Location>
<% end %>
<% if @proxy_dest -%>
<% Array(@no_proxy_uris).each do |uri| %>
  ProxyPass        <%= uri %> !
<% end %>
  ProxyPass          / <%= @proxy_dest %>/
  <Location          />
    ProxyPassReverse /
  </Location>
<% end -%>
