<IfModule mpm_itk_module>
  StartServers        <%= @startservers %>
  MinSpareServers     <%= @minspareservers %>
  MaxSpareServers     <%= @maxspareservers %>
  ServerLimit         <%= @serverlimit %>
  MaxClients          <%= @maxclients %>
  MaxRequestsPerChild <%= @maxrequestsperchild %>
</IfModule>
